dnl @(#) $Header: aclocal.m4,v 1.4 95/11/28 19:06:12 leres Locked $ (LBL)
dnl
dnl LBL autoconf macros
dnl

dnl
dnl Determine which compiler we're using (cc or gcc)
dnl If using gcc, determine the version number
dnl If using cc, require that it support ansi prototypes
dnl If using gcc, use -O2 (otherwise use -O)
dnl If using cc, explicitly specify /usr/local/include
dnl
dnl usage:
dnl
dnl	AC_LBL_C_INIT(copt, incls)
dnl
dnl results:
dnl
dnl	$1 (copt set)
dnl	$2 (incls set)
dnl	CC
dnl	ac_cv_gcc_vers
dnl
AC_DEFUN(AC_LBL_C_INIT,
    [$1=-O
    $2=""
    AC_PROG_CC
    if test $CC = gcc ; then
	    AC_MSG_CHECKING(gcc version)
	    AC_CACHE_VAL(ac_cv_gcc_vers,
		ac_cv_gcc_vers=`gcc -v 2>&1 | \
		    sed -n -e '$s/.* //' -e '$s/\..*//p'`)
	    AC_MSG_RESULT($ac_cv_gcc_vers)
	    if test $ac_cv_gcc_vers -gt 1 ; then
		    $1=-O2
	    fi
    else
	    AC_MSG_CHECKING(that $CC handles ansi prototypes)
	    AC_CACHE_VAL(ac_cv_cc_ansi_prototypes,
		AC_TRY_LINK(
		    [#include <sys/types.h>],
		    [int frob(int, char *)],
		    ac_cv_cc_ansi_prototypes=1,
		    ac_cv_cc_ansi_prototypes=0))
	    if test $ac_cv_cc_ansi_prototypes -eq 1 ; then
		    AC_MSG_RESULT(yes)
	    else
		    AC_MSG_RESULT(no)
		    AC_MSG_ERROR(see the README for more info)
	    fi
	    $2=-I/usr/local/include
    fi
])

dnl
dnl Use pfopen.c if available and pfopen() not in standard libraries
dnl Require libpcap
dnl Look for libpcap in ..
dnl Use the installed libpcap if there is no local version
dnl
dnl usage:
dnl
dnl	AC_LBL_LIBPCAP(pcapdep, incls)
dnl
dnl results:
dnl
dnl	$1 (pcapdep set)
dnl	$2 (incls appended)
dnl	LIBS
dnl
AC_DEFUN(AC_LBL_LIBPCAP,
    [pfopen=/usr/examples/packetfilter/pfopen.c
    if test -f $pfopen ; then
	    AC_CHECK_FUNCS(pfopen)
	    if test $ac_cv_func_pfopen = "no" ; then
		    AC_MSG_RESULT(Using $pfopen)
		    LIBS="$LIBS $pfopen"
	    fi
    fi
    AC_MSG_CHECKING(for local pcap library)
    libpcap=FAIL
    places=`ls .. | sed -e 's,/$,,' -e 's,^,../,' | \
	egrep '/libpcap-[[0-9]]*\.[[0-9]]*(\.[[0-9]]*)?([[ab]][[0-9]]*)?$'`
    for dir in ../libpcap $places libpcap ; do
	    if test -r $dir/pcap.c ; then
		    libpcap=$dir/libpcap.a
		    d=$dir
		    dnl continue and select the last one that exists
	    fi
    done
    if test $libpcap = FAIL ; then
	    AC_MSG_RESULT(not found)
	    AC_CHECK_LIB(pcap, main, libpcap="-lpcap")
	    if test $libpcap = FAIL ; then
		    AC_MSG_ERROR(see the INSTALL doc for more info)
	    fi
    else
	    $2="$$2 -I$d"
	    AC_MSG_RESULT($libpcap)
    fi
    $1=$libpcap
    LIBS="$libpcap $LIBS"])

dnl
dnl Define RETSIGTYPE and RETSIGVAL
dnl
dnl usage:
dnl
dnl	AC_LBL_TYPE_SIGNAL
dnl
dnl results:
dnl
dnl	RETSIGTYPE (defined)
dnl	RETSIGVAL (defined)
dnl
AC_DEFUN(AC_LBL_TYPE_SIGNAL,
    [AC_TYPE_SIGNAL
    if test "$ac_cv_type_signal" = void ; then
	    AC_DEFINE(RETSIGVAL,)
    else
	    AC_DEFINE(RETSIGVAL,(0))
    fi])

dnl
dnl If using gcc, require that fixincludes has been run
dnl
dnl usage:
dnl
dnl	AC_LBL_FIXINCLUDES
dnl
AC_DEFUN(AC_LBL_FIXINCLUDES,
    [if test $CC = gcc ; then
	    AC_MSG_CHECKING(that fixincludes has been run)
	    AC_CACHE_VAL(ac_cv_gcc_fixincludes,
		AC_TRY_LINK(
		    [/*
		     * This generates a "duplicate case value" when fixincludes
		     * has not be run.
		     */
#		include <sys/types.h>
#		include <sys/time.h>
#		include <sys/ioctl.h>
#		ifdef HAVE_SYS_IOCCOM_H
#		include <sys/ioccom.h>
#		endif],
		    [switch (0) {
		    case _IO('A', 1):;
		    case _IO('B', 1):;
		    }],
		    ac_cv_gcc_fixincludes=1,
		    ac_cv_gcc_fixincludes=0))
	    if test $ac_cv_gcc_fixincludes -eq 1 ; then
		    AC_MSG_RESULT(yes)
	    else
		    # Don't cache failure
		    unset ac_cv_gcc_fixincludes
		    AC_MSG_RESULT(no)
		    AC_MSG_ERROR(see the README for more info)
	    fi
    fi])

dnl
dnl Check for flex, default to lex
dnl Require flex 2.4 or higher
dnl Check for bison, default to yacc
dnl Default to lex/yacc if both flex and bison are not available
dnl Define the yy prefix string if using flex and bison
dnl
dnl usage:
dnl
dnl	AC_LBL_LEX_AND_YACC(lex, yacc, yyprefix)
dnl
dnl results:
dnl
dnl	$1 (lex set)
dnl	$2 (yacc appended)
dnl
AC_DEFUN(AC_LBL_LEX_AND_YACC,
    [AC_CHECK_PROGS($1, flex, lex)
    if test "$$1" = flex ; then
	    # The -V flag was added in 2.4
	    AC_MSG_CHECKING(for flex 2.4 or higher)
	    AC_CACHE_VAL(ac_cv_flex_v24,
		if flex -V >/dev/null 2>&1; then
			ac_cv_flex_v24=1
		else
			ac_cv_flex_v24=0
		fi)
	    if test $ac_cv_flex_v24 != 1 ; then
		    AC_MSG_RESULT(no)
		    s="2.4 or higher required"
		    AC_MSG_WARN(ignoring obsolete flex executable ($s))
		    $1=lex
	    fi
    fi
    if test "$$1" = flex ; then
	    $1="$$1 -P$3"
    fi

    AC_CHECK_PROGS($2, bison, yacc)
    if test "$$2" = bison ; then
	    $2="$$2 -y -p $3"
    fi

    if test "$$1" != lex -a "$$2" = yacc -o "$$1" = lex -a "$$2" != yacc ; then
	    AC_MSG_WARN(don't have both flex and bison; reverting to lex/yacc)
	    $1=lex
	    $2=yacc
    fi])

dnl
dnl Checks to see if union wait is used with WEXITSTATUS()
dnl
dnl usage:
dnl
dnl	AC_LBL_UNION_WAIT
dnl
dnl results:
dnl
dnl	DECLWAITSTATUS (defined)
dnl
AC_DEFUN(AC_LBL_UNION_WAIT,
    [AC_MSG_CHECKING(if union wait is used)
    AC_CACHE_VAL(ac_cv_union_wait,
	AC_TRY_LINK([
    #	include <sys/types.h>
    #	include <sys/wait.h>],
	    [union wait status;
	    u_int i = WEXITSTATUS(status);],
	    ac_cv_union_wait=1,
	    ac_cv_union_wait=0))
    if test $ac_cv_union_wait -eq 1 ; then
	    AC_DEFINE(DECLWAITSTATUS,union wait)
	    AC_MSG_RESULT(yes)
    else
	    AC_DEFINE(DECLWAITSTATUS,int)
	    AC_MSG_RESULT(no)
    fi])

dnl
dnl If using gcc and the file .devel exists:
dnl	Compile with -g and -Wall
dnl	If using gcc 2, do extra prototype checkin
dnl	If an os prototype include exists, symlink os-proto.h to it
dnl
dnl usage:
dnl
dnl	AC_LBL_DEVEL(copt)
dnl
dnl results:
dnl
dnl	$1 (copt appended)
dnl	HAVE_OS_PROTO_H (defined)
dnl	os-proto.h (symlinked)
dnl
AC_DEFUN(AC_LBL_DEVEL,
    [rm -f os-proto.h
    if test $CC = gcc -a -f .devel ; then
	    $1="-g $$1 -Wall"
	    if test $ac_cv_gcc_vers -gt 1 ; then
		    $1="$$1 -Wmissing-prototypes -Wstrict-prototypes"
	    fi
	    os=`echo $target_os | sed -e 's/\([[0-9]]\)[[0-9.]][[0-9.]]*$/\1/'`
	    name="lbl/os-$os.h"
	    if test -f $name ; then
		    ln -s $name os-proto.h
		    AC_DEFINE(HAVE_OS_PROTO_H)
	    else
		    AC_MSG_WARN(can't find $name)
	    fi
    fi])
